#include <gtest/gtest.h>
#include <string>
#include "pugixml.hpp"

#include "Circle.h"
#include "Group.h"
TEST(TestAnalyseXML, TestCircle) {
    std::string s = R"(<?xml version = "1.0"?>
                       <Circle label="testCircle" x="0" y="1" r="2" color="Black" />)";
    pugi::xml_document doc;
    pugi::xml_parse_result result = doc.load_string(s.c_str());
    ASSERT_TRUE(result) << result.description(); // Si jamais result est faux, indique que le test est faux *et* affiche la string result.description() (qui contient la raison de l'erreur)
    pugi::xml_node node = doc.child("Circle");
    Circle c{ node.attribute("label").as_string(),
              node.attribute("x").as_double(),
              node.attribute("y").as_double(),
              node.attribute("r").as_double(),
              node.attribute("color").as_string() };
    std::string c_dump_ref =
R"(Circle "testCircle", x: 0, y: 1, r: 2, color: "Black"
)";
    EXPECT_EQ(c.dump(), c_dump_ref);
}

TEST(TestAnalyseXML, TestGroup) {
    std::string s = R"(<?xml version = "1.0"?>
                       <Group label="testGroup" x="0" y="1">
                           <Circle label="testCircle1" x="2" y="3" r="4" color="Black"/>
                           <Circle label="testCircle2" x="5" y="6" r="7" color="Black"/>
                       </Group>)";
    pugi::xml_document doc;
    pugi::xml_parse_result result = doc.load_string(s.c_str());
    ASSERT_TRUE(result) << result.description(); // Si jamais result est faux, indique que le test est faux *et* affiche la string result.description() (qui contient la raison de l'erreur)
    pugi::xml_node nodeGroup = doc.child("Group");
    Group g{ nodeGroup.attribute("label").as_string(),
             nodeGroup.attribute("x").as_double(),
             nodeGroup.attribute("y").as_double() };
    for (pugi::xml_node nodeCircle : nodeGroup.children("Circle"))
    {
        Circle c{ nodeCircle.attribute("label").as_string(),
                  nodeCircle.attribute("x").as_double(),
                  nodeCircle.attribute("y").as_double(),
                  nodeCircle.attribute("r").as_double(),
                  nodeCircle.attribute("color").as_string() };
        g.children.push_back(c);
    }
    std::string g_dump_ref =
R"(Group "testGroup", x: 0, y: 1, children: [
| Circle "testCircle1", x: 2, y: 3, r: 4, color: "Black"
| Circle "testCircle2", x: 5, y: 6, r: 7, color: "Black"
]
)";
    EXPECT_EQ(g.dump(), g_dump_ref);
}

